@@ -42,8 +42,8 @@ test_that("gasfluxes returns expected values", {
                               robust.linear.C0 = c(0.308970790118557, 
                                                    0.475855538008889, 0.473272206610976, 0.339838564756016, 
                                                    0.333253184107449), 
-                              robust.linear.weights = c("1,1,1,1", 
-                                                        "1,1,1,1", "1,1,0.16,1", "1,0.15,1,1", "1,1,1,1"), 
+                              robust.linear.weights = c("1|1|1|1", 
+                                                        "1|1|1|1", "1|1|0.16|1", "1|0.15|1|1", "1|1|1|1"), 
                               robust.linear.diagnostics = c("", 
                                                             "", "", "", ""), 
                               HMR.f0 = c(NA, NA, -0.123566162944742, NA, 
